@@ -1,13 +1,13 @@
 ;;; vlf.el --- View Large Files  -*- lexical-binding: t -*-
 
-;; Copyright (C) 2006, 2012-2015 Free Software Foundation, Inc.
+;; Copyright (C) 2006, 2012-2017 Free Software Foundation, Inc.
 
-;; Version: 1.7
+;; Version: 1.7.1
 ;; Keywords: large files, utilities
 ;; Maintainer: Andrey Kotlarski <m00naticus@gmail.com>
 ;; Authors: 2006 Mathias Dahl <mathias.dahl@gmail.com>
 ;;          2012 Sam Steingold <sds@gnu.org>
-;;          2013-2015 Andrey Kotlarski <m00naticus@gmail.com>
+;;          2013-2017 Andrey Kotlarski <m00naticus@gmail.com>
 ;; URL: https://github.com/m00natic/vlfi
 
 ;; This file is free software; you can redistribute it and/or modify
@@ -53,6 +53,10 @@ One argument is supplied that specifies current action.  Possible
 values are: `write', `ediff', `occur', `search', `goto-line'."
   :group 'vlf :type 'hook)
 
+(defcustom vlf-batch-size-remote 1024
+  "Defines size (in bytes) of a batch of file data when accessed remotely."
+  :group 'vlf :type 'integer)
+
 (defvar hexl-bits)
 
 (autoload 'vlf-write "vlf-write" "Write current chunk to file." t)
@@ -105,8 +109,8 @@ values are: `write', `ediff', `occur', `search', `goto-line'."
   "Mode to browse large files in."
   :group 'vlf :keymap vlf-prefix-map
   :lighter (:eval (format " VLF[%d/%d](%s)"
-                          (/ vlf-end-pos vlf-batch-size)
-                          (/ vlf-file-size vlf-batch-size)
+                          (ceiling vlf-end-pos vlf-batch-size)
+                          (ceiling vlf-file-size vlf-batch-size)
                           (file-size-human-readable vlf-file-size)))
   (cond (vlf-mode
          (set (make-local-variable 'require-final-newline) nil)
@@ -172,8 +176,10 @@ Return newly created buffer."
     (set-buffer vlf-buffer)
     (set-visited-file-name file)
     (set-buffer-modified-p nil)
-    (if (or minimal (file-remote-p file))
-        (set (make-local-variable 'vlf-batch-size) 1024))
+    (cond (minimal
+           (set (make-local-variable 'vlf-batch-size) 1024))
+          ((file-remote-p file)
+           (set (make-local-variable 'vlf-batch-size) vlf-batch-size-remote)))
     (vlf-mode 1)
     (when minimal                 ;restore batch size to default value
       (kill-local-variable 'vlf-batch-size)
